@@ -1,5 +1,5 @@
 package MyTestServer;
-our $VERSION = '0.8002';
+our $VERSION = '0.8003';
 
 
 
@@ -10,6 +10,12 @@ use base 'AnyEvent::Mojo::Server';
 use AnyEvent::HTTP;
 use Test::More;
 
+{
+  ## Thou shall not use a proxy for localhost
+  no warnings;
+  undef $AnyEvent::HTTP::PROXY;
+}
+
 BEGIN {
   __PACKAGE__->attr('banner_called');
 }
